@@ -46,7 +46,7 @@ class Driver(object):
 
     @property
     @abc.abstractmethod
-    def name(self):  # pragma: no cover
+    def name(self) -> str:  # pragma: no cover
         """
         Name of the driver and returns a string.
 
@@ -54,9 +54,8 @@ class Driver(object):
         """
         pass
 
-    @name.setter
-    @abc.abstractmethod
-    def name(self, value):  # pragma: no cover
+    @name.setter  # type: ignore
+    def name(self, value: str) -> None:  # pragma: no cover
         """
         Driver name setter and returns None.
 
