@@ -426,7 +426,9 @@ class Ansible(base.Base):
             collections_paths_list.append(util.abs_path(collection_path))
         collections_paths_list.extend(
             [
-                util.abs_path(os.path.join(os.path.expanduser("~"), ".ansible")),
+                util.abs_path(
+                    os.path.join(os.path.expanduser("~"), ".ansible/collections")
+                ),
                 "/usr/share/ansible/collections",
                 "/etc/ansible/collections",
             ]
@@ -631,7 +633,7 @@ class Ansible(base.Base):
     def config_file(self):
         return os.path.join(self._config.scenario.ephemeral_directory, "ansible.cfg")
 
-    @property
+    @property  # type: ignore
     @util.lru_cache()
     def playbooks(self):
         return ansible_playbooks.AnsiblePlaybooks(self._config)
